@@ -23,15 +23,7 @@
 ******************************************************************************/
 #include "avicore.h"
 #include "avifmt.h"
-#ifdef HAVE_FCNTL_H
-# include <fcntl.h>
-#endif
-#ifdef HAVE_SYS_FILE_H
-# include <sys/file.h>
-#endif
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
-#endif
+#include "misc/fileio.h"
 #include "misc/misc.h"
 
 
@@ -171,16 +163,9 @@ void avi_split_file(AviEdit *avi_edit,const gint pos)
 
 	/* ΥեʬΥ */
 	avi_file=g_malloc(sizeof(AviFile));
-	if (avi_edit->file->fd!=-1) {
-		if ((avi_file->fd=open(avi_edit->file->name,O_RDONLY))==-1)
-			avi_file->fd=dup(avi_edit->file->fd);
-#ifdef HAVE_FLOCK
-		else
-			flock(avi_file->fd,LOCK_SH);
-#endif
-	} else {
-		avi_file->fd=-1;
-	}
+	avi_file->fio = avi_edit->file->fio != NULL
+					? fileio_open (avi_edit->file->name, FILEIO_ACCESS_READ,
+						FILEIO_SHARE_READ, FILEIO_MODE_OPEN_EXISTING) : NULL;
 	avi_file->data=avi_edit->file->data!=NULL && avi_edit->file->bmih!=NULL
 		?g_memdup(avi_edit->file->data,bm_image_bytes(avi_edit->file->bmih))
 																		:NULL;
@@ -216,7 +201,7 @@ void avi_split_file(AviEdit *avi_edit,const gint pos)
 /*	AVIAVIե빽¤Τ
 	    file,ե̾
 	   param,ȥ꡼ֹ
-	    type,streamtypeAUDIO/streamtypeVIDEO
+	    type,AVI_STREAM_AUDIO/AVI_STREAM_VIDEO
 	    rate,졼
 	   scale,
 	priority,ͥ
@@ -231,7 +216,7 @@ avi_open_avi (const gchar *file, const gint param,
 	gchar *strn;
 	gint i, j;
 	guint32 id, size;
-	off_t offset;				/* AVIΥࡼӡ */
+	goffset offset;				/* AVIΥࡼӡ */
 	AviFile *avi_file;
 	AviBaseIndex abi;
 	AviBaseIndexEntry abe;
@@ -243,135 +228,128 @@ avi_open_avi (const gchar *file, const gint param,
 
 	avi_file = g_malloc0 (sizeof (AviFile));
 	/* ե򳫤 */
-	avi_file->fd = open (file, O_RDONLY);
-	if (avi_file->fd == -1)
+	avi_file->fio = fileio_open (file, FILEIO_ACCESS_READ,
+								FILEIO_SHARE_READ, FILEIO_MODE_OPEN_EXISTING);
+	if (avi_file->fio == NULL)
 	  {
 		g_free (avi_file);
 		return NULL;
 	  }
-#ifdef HAVE_FLOCK
-	if (flock (avi_file->fd, LOCK_SH) != 0)
-	  {
-		close (avi_file->fd);
-		g_free (avi_file);
-		return NULL;
-	  }
-#endif
 	/* եǥ꥿󥯥ݥ󥿤 */
-	ck = chunk_open (avi_file->fd);
+	ck = chunk_open (avi_file->fio);
 	/* RIFF󥯤 */
-	if (!chunk_in (avi_file->fd, ck))
+	if (!chunk_in (avi_file->fio, ck))
 	  {
 		chunk_free (ck);
-		close (avi_file->fd);
+		fileio_close (avi_file->fio);
 		g_free (avi_file);
 		return NULL;
 	  }
 	/* եबhdrlLIST󥯤õ */
-	while (chunk_form (avi_file->fd) != listtypeAVIHEADER)
-		if (!chunk_next (avi_file->fd, ck))
+	while (chunk_form (avi_file->fio) != CK_LIST_AVIHEADER)
+		if (!chunk_next (avi_file->fio, ck))
 		  {
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (avi_file);
 			return NULL;
 		  }
 	/* եबhdrlLIST󥯤(RIFF'AVI ' -> LIST'hdrl') */
-	if (!chunk_in (avi_file->fd, ck))
+	if (!chunk_in (avi_file->fio, ck))
 	  {
 		chunk_free (ck);
-		close (avi_file->fd);
+		fileio_close (avi_file->fio);
 		g_free (avi_file);
 		return NULL;
 	  }
 	/* եबstrlLIST󥯤õ */
 	for (i = 0;i <= param; i++)
 		do
-			if (!chunk_next (avi_file->fd, ck))
+			if (!chunk_next (avi_file->fio, ck))
 			  {
 				chunk_free (ck);
-				close (avi_file->fd);
+				fileio_close (avi_file->fio);
 				g_free (avi_file);
 				return NULL;
 			  }
-		while (chunk_form (avi_file->fd) != listtypeSTREAMHEADER);
+		while (chunk_form (avi_file->fio) != CK_LIST_STREAMHEADER);
 	/* եबstrlLIST󥯤
 									(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl') */
-	if (!chunk_in (avi_file->fd, ck))
+	if (!chunk_in (avi_file->fio, ck))
 	  {
 		chunk_free (ck);
-		close (avi_file->fd);
+		fileio_close (avi_file->fio);
 		g_free (avi_file);
 		return NULL;
 	  }
 	/* strh󥯤õ(AviStreamHeader) */
-	while (chunk_id (avi_file->fd) != ckidSTREAMHEADER)
-		if (!chunk_next (avi_file->fd, ck))
+	while (chunk_id (avi_file->fio) != CK_ID_STREAMHEADER)
+		if (!chunk_next (avi_file->fio, ck))
 		  {
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (avi_file);
 			return NULL;
 		  }
 	/* strh󥯤Υ(AviStreamHeader) */
-	if ((size = chunk_size (avi_file->fd)) == -1 || size < ASH_SIZE)
+	if ((size = chunk_size (avi_file->fio)) == -1 || size < ASH_SIZE)
 	  {
 		chunk_free (ck);
-		close (avi_file->fd);
+		fileio_close (avi_file->fio);
 		g_free (avi_file);
 		return NULL;
 	  }
 	ash = g_malloc (ASH_SIZE);
 	/* strh󥯤(AVIStreamHeader)
 							(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl' -> strh) */
-	if (!chunk_in (avi_file->fd, ck)
+	if (!chunk_in (avi_file->fio, ck)
 		/* AviStreamHeaderɤ߹ */
-				|| read (avi_file->fd, ash, ASH_SIZE) != ASH_SIZE
+				|| fileio_read (avi_file->fio, ash, ASH_SIZE) != ASH_SIZE
 		/*  */
-				|| (ash_get_type (ash) != streamtypeAUDIO
-									&& ash_get_type (ash) != streamtypeVIDEO)
+				|| (ash_get_type (ash) != AVI_STREAM_AUDIO
+									&& ash_get_type (ash) != AVI_STREAM_VIDEO)
 		/* strh󥯤Ф(AVIStreamHeader)
 							(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl' <- strh) */
-				|| !chunk_out (avi_file->fd, ck)
+				|| !chunk_out (avi_file->fio, ck)
 		/* եबstrlLIST󥯤Ф
 									(RIFF'AVI ' -> LIST'hdrl' <- LIST'strl') */
-				|| !chunk_out (avi_file->fd, ck)
+				|| !chunk_out (avi_file->fio, ck)
 		/* եबstrlLIST󥯤
 									(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl') */
-				|| !chunk_in (avi_file->fd, ck))
+				|| !chunk_in (avi_file->fio, ck))
 	  {
 		chunk_free (ck);
-		close (avi_file->fd);
+		fileio_close (avi_file->fio);
 		g_free (ash);
 		g_free (avi_file);
 		return NULL;
 	  }
 	/* strf󥯤õ(BitmapInfoHeader)|(WaveFormatEx) */
-	while (chunk_id (avi_file->fd) != ckidSTREAMFORMAT)
-		if (!chunk_next (avi_file->fd, ck))
+	while (chunk_id (avi_file->fio) != CK_ID_STREAMFORMAT)
+		if (!chunk_next (avi_file->fio, ck))
 		  {
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file);
 			return NULL;
 		  }
 	/* strf󥯤Υ(BitmapInfoHeader)|(WaveFormatEx) */
-	size = chunk_size (avi_file->fd);
+	size = chunk_size (avi_file->fio);
 	if (size == -1)
 	  {
 		chunk_free (ck);
-		close (avi_file->fd);
+		fileio_close (avi_file->fio);
 		g_free (ash);
 		g_free (avi_file);
 		return NULL;
 	  }
-	if (ash_get_type (ash) == streamtypeVIDEO)
+	if (ash_get_type (ash) == AVI_STREAM_VIDEO)
 	  {
 		if (size < BMIH_SIZE)
 		  {
 			chunk_free (ck);
-			close(avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file);
 			return NULL;
@@ -383,7 +361,7 @@ avi_open_avi (const gchar *file, const gint param,
 		if (size < WFX_SIZE - sizeof (guint16))
 		  {
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file);
 			return NULL;
@@ -393,22 +371,22 @@ avi_open_avi (const gchar *file, const gint param,
 	  }
 	/* strf󥯤(BitmapInfoHeader)|(WaveFormatEx)
 							(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl' -> strf) */
-	if (!chunk_in (avi_file->fd, ck)
+	if (!chunk_in (avi_file->fio, ck)
 		/* BitmapInfoHeader|WaveFormatExɤ߹ */
-		|| read (avi_file->fd, ash_get_type (ash) == streamtypeVIDEO
+		|| fileio_read (avi_file->fio, ash_get_type (ash) == AVI_STREAM_VIDEO
 			? (gpointer)avi_file->bmih : (gpointer)avi_file->wfx, size) != size
 		/* strf󥯤Ф(BitmapInfoHeader)|(WaveFormatEx)
 							(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl' <- strh) */
-		|| !chunk_out (avi_file->fd, ck)
+		|| !chunk_out (avi_file->fio, ck)
 		/* եबstrlLIST󥯤Ф
 									(RIFF'AVI ' -> LIST'hdrl' <- LIST'strl') */
-		|| !chunk_out (avi_file->fd, ck)
+		|| !chunk_out (avi_file->fio, ck)
 		/* եबstrlLIST󥯤
 									(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl') */
-		|| !chunk_in (avi_file->fd, ck))
+		|| !chunk_in (avi_file->fio, ck))
 	  {
 		chunk_free (ck);
-		close (avi_file->fd);
+		fileio_close (avi_file->fio);
 		g_free (ash);
 		g_free (avi_file->bmih);
 		g_free (avi_file->wfx);
@@ -419,17 +397,17 @@ avi_open_avi (const gchar *file, const gint param,
 	if (name != NULL)
 	  {
 		/* strn󥯤õ */
-		while ((id = chunk_id (avi_file->fd)) != ckidSTREAMNAME)
-			if (!chunk_next (avi_file->fd, ck))
+		while ((id = chunk_id (avi_file->fio)) != CK_ID_STREAMNAME)
+			if (!chunk_next (avi_file->fio, ck))
 				break;
-		if (id == ckidSTREAMNAME)
+		if (id == CK_ID_STREAMNAME)
 		  {
 			/* strn󥯤Υ */
-			size = chunk_size (avi_file->fd);
+			size = chunk_size (avi_file->fio);
 			if (size == -1)
 			  {
 				chunk_free (ck);
-				close (avi_file->fd);
+				fileio_close (avi_file->fio);
 				g_free (ash);
 				g_free (avi_file->bmih);
 				g_free (avi_file->wfx);
@@ -439,16 +417,16 @@ avi_open_avi (const gchar *file, const gint param,
 			strn = g_malloc0 (size + 1);
 			/* strn󥯤
 							(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl' -> strn) */
-			if (!chunk_in (avi_file->fd, ck)
+			if (!chunk_in (avi_file->fio, ck)
 				/* strnɤ߹ */
-					|| read (avi_file->fd, strn, size) != size
+					|| fileio_read (avi_file->fio, strn, size) != size
 				/* strn󥯤Ф
 							(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl' <- strh) */
-					|| !chunk_out (avi_file->fd, ck))
+					|| !chunk_out (avi_file->fio, ck))
 			  {
 				g_free (strn);
 				chunk_free (ck);
-				close (avi_file->fd);
+				fileio_close (avi_file->fio);
 				g_free (ash);
 				g_free (avi_file->bmih);
 				g_free (avi_file->wfx);
@@ -458,14 +436,14 @@ avi_open_avi (const gchar *file, const gint param,
 		  }
 		/* եबstrlLIST󥯤Ф
 									(RIFF'AVI ' -> LIST'hdrl' <- LIST'strl') */
-		if (!chunk_out (avi_file->fd, ck)
+		if (!chunk_out (avi_file->fio, ck)
 			/* եबstrlLIST󥯤
 									(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl') */
-				|| !chunk_in (avi_file->fd, ck))
+				|| !chunk_in (avi_file->fio, ck))
 		  {
 			g_free (strn);
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file->bmih);
 			g_free (avi_file->wfx);
@@ -477,23 +455,23 @@ avi_open_avi (const gchar *file, const gint param,
 	/* ѡǥå󥯤ذư */
 
 	/* ѡǥå󥯤õ */
-	while ((id = chunk_id (avi_file->fd)) != ckidAVISUPERINDEX)
-		if (!chunk_next (avi_file->fd, ck))
+	while ((id = chunk_id (avi_file->fio)) != CK_ID_AVISUPERINDEX)
+		if (!chunk_next (avi_file->fio, ck))
 			break;
-	if (id == ckidAVISUPERINDEX)
+	if (id == CK_ID_AVISUPERINDEX)
 	  {
 		/* ѡǥå󥯤Υ */
-		size = chunk_size (avi_file->fd);
+		size = chunk_size (avi_file->fio);
 		if (size == -1	/* ѡǥå󥯤
 							(RIFF'AVI ' -> LIST'hdrl' -> LIST'strl' -> indx) */
-						|| !chunk_in (avi_file->fd, ck)
-						/* indxɤ߹ */
-						|| read (avi_file->fd, &asi, ASI_SIZE) != ASI_SIZE
-						|| size < ASI_SIZE + asi_get_entries (&asi) * ASE_SIZE)
+					|| !chunk_in (avi_file->fio, ck)
+					/* indxɤ߹ */
+					|| fileio_read (avi_file->fio, &asi, ASI_SIZE) != ASI_SIZE
+					|| size < ASI_SIZE + asi_get_entries (&asi) * ASE_SIZE)
 		  {
 			g_free (strn);
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file->bmih);
 			g_free (avi_file->wfx);
@@ -501,16 +479,16 @@ avi_open_avi (const gchar *file, const gint param,
 			return NULL;
 		  }
 		if (asi_get_longs (&asi) == 4
-							&& asi_get_sub_type (&asi) == AVI_INDEX_SUB_DEFAULT
-								&& asi_get_type (&asi) == AVI_INDEX_OF_INDEXES)
+							&& asi_get_sub_type (&asi) == AVI_IDX_SUB_DEFAULT
+								&& asi_get_type (&asi) == AVI_IDX_OF_INDEXES)
 			for (i = 0; i < asi_get_entries (&asi); i++)
 			  {
 				/* ѡǥåȥ꡼ɤ߹ */
-				if (read (avi_file->fd, &ase, ASE_SIZE) != ASE_SIZE)
+				if (fileio_read (avi_file->fio, &ase, ASE_SIZE) != ASE_SIZE)
 				  {
 					g_free (strn);
 					chunk_free (ck);
-					close (avi_file->fd);
+					fileio_close (avi_file->fio);
 					g_free (ash);
 					g_free (avi_file->index);
 					g_free (avi_file);
@@ -519,17 +497,18 @@ avi_open_avi (const gchar *file, const gint param,
 				if (ase_get_offset (&ase) != 0)
 				  {
 					/* եΥեåȤ */
-					offset = lseek (avi_file->fd, 0, SEEK_CUR);
+					offset = fileio_seek (avi_file->fio, 0, FILEIO_SEEK_CUR);
 					/* եΥեåȤꤹ */
-					if (offset == -1 || lseek (avi_file->fd,
-							ase_get_offset (&ase) + sizeof (guint32) * 2,
-																SEEK_SET) == -1
+					if (offset == -1 || fileio_seek (avi_file->fio,
+								ase_get_offset (&ase) + sizeof (guint32) * 2,
+														FILEIO_SEEK_SET) == -1
 							/* ix##ɤ߹ */
-							|| read (avi_file->fd, &abi, ABI_SIZE) != ABI_SIZE)
+								|| fileio_read (avi_file->fio, &abi, ABI_SIZE)
+																!= ABI_SIZE)
 					  {
 						g_free (strn);
 						chunk_free (ck);
-						close (avi_file->fd);
+						fileio_close (avi_file->fio);
 						g_free (ash);
 						g_free (avi_file->index);
 						g_free (avi_file->bmih);
@@ -539,7 +518,7 @@ avi_open_avi (const gchar *file, const gint param,
 					  }
 					if (abi_get_longs (&abi) == 2
 						&& asi_get_sub_type (&asi) == abi_get_sub_type (&abi)
-								&& abi_get_type (&abi) == AVI_INDEX_OF_CHUNKS)
+								&& abi_get_type (&abi) == AVI_IDX_OF_CHUNKS)
 					  {
 						avi_file->index = g_realloc (avi_file->index,
 								(avi_file->entries + abi_get_entries (&abi))
@@ -547,12 +526,12 @@ avi_open_avi (const gchar *file, const gint param,
 						for (j = 0; j < abi_get_entries (&abi); j++)
 						  {
 							/* ѡǥåȥ꡼ɤ߹ */
-							if (read (avi_file->fd, &abe, ABE_SIZE)
+							if (fileio_read (avi_file->fio, &abe, ABE_SIZE)
 																!= ABE_SIZE)
 							  {
 								g_free (strn);
 								chunk_free (ck);
-								close (avi_file->fd);
+								fileio_close (avi_file->fio);
 								g_free (ash);
 								g_free (avi_file->index);
 								g_free (avi_file->bmih);
@@ -567,16 +546,17 @@ avi_open_avi (const gchar *file, const gint param,
 									= (abe_get_size (&abe) & 0x7fffffff);
 							avi_file->index[avi_file->entries].flags
 									= (abe_get_size (&abe) & 0x80000000) == 0
-														? AVIIF_KEYFRAME : 0;
+														? AVI_IF_KEYFRAME : 0;
 							avi_file->entries++;
 						  }
 					  }
 					/* եΥեåȤꤹ */
-					if (lseek (avi_file->fd, offset, SEEK_SET) == -1)
+					if (fileio_seek (avi_file->fio, offset, FILEIO_SEEK_SET)
+																		== -1)
 					  {
 						g_free (strn);
 						chunk_free (ck);
-						close (avi_file->fd);
+						fileio_close (avi_file->fio);
 						g_free (ash);
 						g_free (avi_file->index);
 						g_free (avi_file->bmih);
@@ -592,7 +572,7 @@ avi_open_avi (const gchar *file, const gint param,
 	if (!chunk_free (ck))
 	  {
 		g_free (strn);
-		close (avi_file->fd);
+		fileio_close (avi_file->fio);
 		g_free (ash);
 		g_free (avi_file->index);
 		g_free (avi_file->bmih);
@@ -606,13 +586,13 @@ avi_open_avi (const gchar *file, const gint param,
 		/* ࡼӡ󥯤ذư */
 
 		/* եǥ꥿󥯥ݥ󥿤 */
-		ck = chunk_open (avi_file->fd);
+		ck = chunk_open (avi_file->fio);
 		/* RIFF󥯤 */
-		if (!chunk_in (avi_file->fd, ck))
+		if (!chunk_in (avi_file->fio, ck))
 		  {
 			g_free (strn);
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file->bmih);
 			g_free (avi_file->wfx);
@@ -620,12 +600,12 @@ avi_open_avi (const gchar *file, const gint param,
 			return NULL;
 		  }
 		/* movi󥯤õ */
-		while (chunk_form (avi_file->fd) != listtypeAVIMOVIE)
-			if (!chunk_next (avi_file->fd, ck))
+		while (chunk_form (avi_file->fio) != CK_LIST_AVIMOVIE)
+			if (!chunk_next (avi_file->fio, ck))
 			  {
 				g_free (strn);
 				chunk_free (ck);
-				close (avi_file->fd);
+				fileio_close (avi_file->fio);
 				g_free (ash);
 				g_free (avi_file->bmih);
 				g_free (avi_file->wfx);
@@ -633,12 +613,12 @@ avi_open_avi (const gchar *file, const gint param,
 				return NULL;
 			}
 		/* եΥեåȤ */
-		offset = lseek (avi_file->fd, 0, SEEK_CUR);
+		offset = fileio_seek (avi_file->fio, 0, FILEIO_SEEK_CUR);
 		if (offset == -1)
 		  {
 			g_free (strn);
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file->bmih);
 			g_free (avi_file->wfx);
@@ -650,7 +630,7 @@ avi_open_avi (const gchar *file, const gint param,
 		if (!chunk_free (ck))
 		  {
 			g_free (strn);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file->bmih);
 			g_free (avi_file->wfx);
@@ -661,13 +641,13 @@ avi_open_avi (const gchar *file, const gint param,
 		/* ǥå󥯤ذư */
 
 		/* եǥ꥿󥯥ݥ󥿤 */
-		ck = chunk_open (avi_file->fd);
+		ck = chunk_open (avi_file->fio);
 		/* RIFF󥯤 */
-		if (!chunk_in (avi_file->fd, ck))
+		if (!chunk_in (avi_file->fio, ck))
 		  {
 			g_free (strn);
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file->bmih);
 			g_free (avi_file->wfx);
@@ -675,12 +655,12 @@ avi_open_avi (const gchar *file, const gint param,
 			return NULL;
 		  }
 		/* idx1󥯤õ */
-		while (chunk_id (avi_file->fd) != ckidAVINEWINDEX)
-			if (!chunk_next (avi_file->fd, ck))
+		while (chunk_id (avi_file->fio) != CK_ID_AVINEWINDEX)
+			if (!chunk_next (avi_file->fio, ck))
 			  {
 				g_free (strn);
 				chunk_free (ck);
-				close (avi_file->fd);
+				fileio_close (avi_file->fio);
 				g_free (ash);
 				g_free (avi_file->bmih);
 				g_free (avi_file->wfx);
@@ -689,12 +669,12 @@ avi_open_avi (const gchar *file, const gint param,
 			}
 		/* idx1󥯤Υ */
 		/* idx1󥯤(RIFF'AVI ' -> idx1) */
-		size = chunk_size (avi_file->fd);
-		if (size == -1 || !chunk_in (avi_file->fd, ck))
+		size = chunk_size (avi_file->fio);
+		if (size == -1 || !chunk_in (avi_file->fio, ck))
 		  {
 			g_free (strn);
 			chunk_free (ck);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file->bmih);
 			g_free (avi_file->wfx);
@@ -704,11 +684,11 @@ avi_open_avi (const gchar *file, const gint param,
 		/* ǥåɤ߹ */
 		for (i = 0; i < size / AIE_SIZE; i++)
 		  {
-			if (read (avi_file->fd, &aie, AIE_SIZE) != AIE_SIZE)
+			if (fileio_read (avi_file->fio, &aie, AIE_SIZE) != AIE_SIZE)
 			  {
 				g_free (strn);
 				chunk_free (ck);
-				close (avi_file->fd);
+				fileio_close (avi_file->fio);
 				g_free (ash);
 				g_free (avi_file->index);
 				g_free (avi_file->bmih);
@@ -735,7 +715,7 @@ avi_open_avi (const gchar *file, const gint param,
 		if (!chunk_free (ck))
 		  {
 			g_free (strn);
-			close (avi_file->fd);
+			fileio_close (avi_file->fio);
 			g_free (ash);
 			g_free (avi_file->bmih);
 			g_free (avi_file->wfx);
@@ -744,7 +724,7 @@ avi_open_avi (const gchar *file, const gint param,
 		  }
 	  }
 	/* ǥåȥإå */
-	if (ash_get_type (ash) == streamtypeVIDEO)
+	if (ash_get_type (ash) == AVI_STREAM_VIDEO)
 	  {
 		avi_file->length = avi_file->entries;
 	  }
@@ -777,7 +757,8 @@ avi_open_avi (const gchar *file, const gint param,
 /*	ӥåȥޥåפAVIե빽¤Τ
 	file,ե̾
 	 RET,AVIե빽¤,NULL:顼										*/
-static AviFile *avi_open_bitmap(const gchar *file)
+static AviFile *
+avi_open_bitmap (const gchar *file)
 {
 	guint32 size;
 	AviFile *avi_file;
@@ -785,102 +766,110 @@ static AviFile *avi_open_bitmap(const gchar *file)
 
 	avi_file = g_malloc0 (sizeof (AviFile));
 	/* ե򳫤 */
-	if ((avi_file->fd=open(file,O_RDONLY))==-1) {
-		g_free(avi_file);
-		return NULL;
-	}
-#ifdef HAVE_FLOCK
-	if (flock (avi_file->fd, LOCK_SH) != 0)
+	/* ե򳫤 */
+	avi_file->fio = fileio_open (file, FILEIO_ACCESS_READ,
+								FILEIO_SHARE_READ, FILEIO_MODE_OPEN_EXISTING);
+	if (avi_file->fio == NULL)
 	  {
-		close (avi_file->fd);
 		g_free (avi_file);
 		return NULL;
 	  }
-#endif
 	/* ˥إåɤ߹ */
-	if (lseek(avi_file->fd,BMFH_SIZE,SEEK_SET)==-1) {
-		close(avi_file->fd);
-		g_free(avi_file);
+	if (fileio_seek(avi_file->fio, BMFH_SIZE, FILEIO_SEEK_SET) == -1)
+	  {
+		fileio_close (avi_file->fio);
+		g_free (avi_file);
 		return NULL;
-	}
-	avi_file->bmih=g_malloc(BMIH_SIZE);
-	if (read(avi_file->fd,avi_file->bmih,BMIH_SIZE)!=BMIH_SIZE) {
-		close(avi_file->fd);
-		g_free(avi_file);
+	  }
+	avi_file->bmih = g_malloc (BMIH_SIZE);
+	if (fileio_read (avi_file->fio, avi_file->bmih, BMIH_SIZE) != BMIH_SIZE)
+	  {
+		fileio_close (avi_file->fio);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 	/* إåΥ׻ */
-	size=bm_header_bytes(avi_file->bmih);
+	size = bm_header_bytes (avi_file->bmih);
 	/* إåɤ߹ */
-	avi_file->bmih=g_realloc(avi_file->bmih,size);
-	if (lseek(avi_file->fd,BMFH_SIZE,SEEK_SET)==-1
-							|| read(avi_file->fd,avi_file->bmih,size)!=size) {
-		close(avi_file->fd);
-		g_free(avi_file->bmih);
-		g_free(avi_file);
+	avi_file->bmih = g_realloc (avi_file->bmih, size);
+	if (fileio_seek (avi_file->fio, BMFH_SIZE, FILEIO_SEEK_SET) == -1
+				|| fileio_read (avi_file->fio, avi_file->bmih, size) != size)
+	  {
+		fileio_close (avi_file->fio);
+		g_free (avi_file->bmih);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 	/* ᡼ɤ߹ */
-	if (bmih_get_compression(avi_file->bmih)==BI_RGB
-					|| bmih_get_compression(avi_file->bmih)==BI_BITFIELDS) {
+	if (bmih_get_compression (avi_file->bmih) == BI_COMP_RGB
+				|| bmih_get_compression (avi_file->bmih) == BI_COMP_BITFIELDS)
+	  {
 		/* ̵ */
-		size=bm_image_bytes(avi_file->bmih);
-		avi_file->data=g_malloc(size);
-		if (read(avi_file->fd,avi_file->data,size)!=size) {
-			close(avi_file->fd);
-			g_free(avi_file->bmih);
-			g_free(avi_file->data);
-			g_free(avi_file);
+		size = bm_image_bytes (avi_file->bmih);
+		avi_file->data = g_malloc (size);
+		if (fileio_read (avi_file->fio, avi_file->data, size) != size)
+		  {
+			fileio_close (avi_file->fio);
+			g_free (avi_file->bmih);
+			g_free (avi_file->data);
+			g_free (avi_file);
 			return NULL;
-		}
-	} else if (bmih_get_compression(avi_file->bmih)==BI_RLE4
-							|| bmih_get_compression(avi_file->bmih)==BI_RLE8) {
+		  }
+	  }
+	else if (bmih_get_compression (avi_file->bmih) == BI_COMP_RLE4
+					|| bmih_get_compression (avi_file->bmih) == BI_COMP_RLE8)
+	  {
 		/*  */
-		bmih0=g_malloc(size+bmih_get_size_image(avi_file->bmih));
-		g_memmove(bmih0,avi_file->bmih,size);
-		if (read(avi_file->fd,(guint8 *)bmih0+size,bmih_get_size_image(bmih0))
-												!=bmih_get_size_image(bmih0)) {
-			g_free(bmih0);
-			close(avi_file->fd);
-			g_free(avi_file->bmih);
-			g_free(avi_file);
+		bmih0 = g_malloc (size + bmih_get_size_image (avi_file->bmih));
+		g_memmove (bmih0, avi_file->bmih, size);
+		if (fileio_read (avi_file->fio, (guint8 *)bmih0 + size,
+				bmih_get_size_image (bmih0)) != bmih_get_size_image (bmih0))
+		  {
+			g_free (bmih0);
+			fileio_close (avi_file->fio);
+			g_free (avi_file->bmih);
+			g_free (avi_file);
 			return NULL;
-		}
-		bmih1=g_malloc(bx_all_bytes(
-				bmih_get_width(bmih0),bmih_get_height(bmih0),
-				bmih_get_bit_count(bmih0),BI_RGB,bmih_get_color_used(bmih0)));
-		bitmap_expand(bmih0,bmih1);
-		g_free(bmih0);
+		  }
+		bmih1 = g_malloc (bx_all_bytes
+							(bmih_get_width (bmih0), bmih_get_height (bmih0),
+									bmih_get_bit_count (bmih0), BI_COMP_RGB,
+												bmih_get_color_used (bmih0)));
+		bitmap_expand (bmih0, bmih1);
+		g_free (bmih0);
 		/* ŸDIB򥳥ԡ */
-		size=bm_header_bytes(bmih1);
-		avi_file->bmih=g_realloc(avi_file->bmih,size);
-		g_memmove(avi_file->bmih,bmih1,size);
-		avi_file->data=g_memdup((guint8 *)bmih1+size,
-											bm_image_bytes(avi_file->bmih));
-		g_free(bmih1);
-	} else {
-		close(avi_file->fd);
-		g_free(avi_file->bmih);
-		g_free(avi_file->data);
-		g_free(avi_file);
+		size = bm_header_bytes (bmih1);
+		avi_file->bmih = g_realloc (avi_file->bmih, size);
+		g_memmove (avi_file->bmih, bmih1, size);
+		avi_file->data = g_memdup((guint8 *)bmih1 + size,
+											bm_image_bytes (avi_file->bmih));
+		g_free (bmih1);
+	  }
+	else
+	  {
+		fileio_close (avi_file->fio);
+		g_free (avi_file->bmih);
+		g_free (avi_file->data);
+		g_free (avi_file);
 		return NULL;
-	}
-	if (close(avi_file->fd)!=0) {
-		g_free(avi_file->bmih);
-		g_free(avi_file->data);
-		g_free(avi_file);
+	  }
+	if (!fileio_close (avi_file->fio))
+	  {
+		g_free (avi_file->bmih);
+		g_free (avi_file->data);
+		g_free (avi_file);
 		return NULL;
-	}
-	avi_file->handler=comptypeDIB;
+	  }
+	avi_file->handler = AVI_STREAM_COMP_DIB;
 	/* ե */
-	avi_file->fd=-1;					/* եǥ꥿ */
-	avi_file->length=1;
-	avi_file->entries=1;				/* ǥåο */
+	avi_file->fio = NULL;				/* եݥ */
+	avi_file->length = 1;
+	avi_file->entries = 1;				/* ǥåο */
 	/* ǥå */
-	avi_file->index=g_malloc(sizeof(AviIndex));
-	avi_file->index[0].offset=0;
-	avi_file->index[0].size=size;
-	avi_file->index[0].flags=0;
+	avi_file->index = g_malloc (sizeof (AviIndex));
+	avi_file->index[0].offset = 0;
+	avi_file->index[0].size = size;
+	avi_file->index[0].flags = 0;
 	return avi_file;
 }
 
@@ -888,128 +877,138 @@ static AviFile *avi_open_bitmap(const gchar *file)
 /*	WAVEե뤫AVIե빽¤Τ
 	file,ե̾
 	 RET,AVIե빽¤,NULL:顼										*/
-static AviFile *avi_open_wave(const gchar *file)
+static AviFile *
+avi_open_wave (const gchar *file)
 {
 	guint32 size;
-	off_t offset;				/* AVIΥࡼӡ */
+	goffset offset;				/* AVIΥࡼӡ */
 	AviFile *avi_file;
 	Chunk *ck;
 
 	avi_file = g_malloc0 (sizeof (AviFile));
 	/* ե򳫤 */
-	if ((avi_file->fd=open(file,O_RDONLY))==-1) {
-		g_free(avi_file);
-		return NULL;
-	}
-#ifdef HAVE_FLOCK
-	if (flock (avi_file->fd, LOCK_SH) != 0)
+	avi_file->fio = fileio_open (file, FILEIO_ACCESS_READ,
+								FILEIO_SHARE_READ, FILEIO_MODE_OPEN_EXISTING);
+	if (avi_file->fio == NULL)
 	  {
-		close (avi_file->fd);
 		g_free (avi_file);
 		return NULL;
 	  }
-#endif
 	/* եǥ꥿󥯥ݥ󥿤 */
-	ck=chunk_open(avi_file->fd);
+	ck = chunk_open (avi_file->fio);
 	/* RIFF󥯤 */
-	if (!chunk_in(avi_file->fd,ck)) {
-		chunk_free(ck);
-		close(avi_file->fd);
-		g_free(avi_file);
+	if (!chunk_in (avi_file->fio, ck))
+	  {
+		chunk_free (ck);
+		fileio_close (avi_file->fio);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 	/* fmt󥯤õ */
-	while (chunk_id(avi_file->fd)!=ckidWAVEFORMAT) {
-		if (!chunk_next(avi_file->fd,ck)) {
-			chunk_free(ck);
-			close(avi_file->fd);
-			g_free(avi_file);
+	while (chunk_id (avi_file->fio) != CK_ID_WAVEFORMAT)
+	  {
+		if (!chunk_next (avi_file->fio, ck))
+		  {
+			chunk_free (ck);
+			fileio_close (avi_file->fio);
+			g_free (avi_file);
 			return NULL;
-		}
-	}
+		  }
+	  }
 	/* fmt󥯤Υ */
 	/* fmt󥯤(RIFF'AVI ' -> fmt) */
-	if ((size=chunk_size(avi_file->fd))==-1 || !chunk_in(avi_file->fd,ck)) {
-		chunk_free(ck);
-		close(avi_file->fd);
-		g_free(avi_file);
+	if ((size = chunk_size(avi_file->fio)) == -1
+											|| !chunk_in (avi_file->fio,ck))
+	  {
+		chunk_free (ck);
+		fileio_close (avi_file->fio);
+		g_free (avi_file);
 		return NULL;
 	}
-	if (size<WFX_SIZE-sizeof(guint16)) {
-		chunk_free(ck);
-		close(avi_file->fd);
-		g_free(avi_file);
+	if (size < WFX_SIZE - sizeof (guint16))
+	  {
+		chunk_free (ck);
+		fileio_close (avi_file->fio);
+		g_free (avi_file);
 		return NULL;
-	}
-	avi_file->wfx=g_malloc(MAX(size,WFX_SIZE));
-	wfx_set_size(avi_file->wfx,0);
+	  }
+	avi_file->wfx = g_malloc (MAX (size, WFX_SIZE));
+	wfx_set_size (avi_file->wfx, 0);
 	/* WaveFormatExɤ߹ */
-	if (read(avi_file->fd,avi_file->wfx,size)!=size) {
-		chunk_free(ck);
-		close(avi_file->fd);
-		g_free(avi_file->wfx);
-		g_free(avi_file);
+	if (fileio_read (avi_file->fio, avi_file->wfx, size) != size)
+	  {
+		chunk_free (ck);
+		fileio_close (avi_file->fio);
+		g_free (avi_file->wfx);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 	/* 󥯥ݥ󥿤 */
-	if (!chunk_free(ck)) {
-		close(avi_file->fd);
-		g_free(avi_file->wfx);
-		g_free(avi_file);
+	if (!chunk_free (ck))
+	  {
+		fileio_close (avi_file->fio);
+		g_free (avi_file->wfx);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 
 	/* եǥ꥿󥯥ݥ󥿤 */
-	ck=chunk_open(avi_file->fd);
+	ck = chunk_open (avi_file->fio);
 	/* RIFF󥯤 */
-	if (!chunk_in(avi_file->fd,ck)) {
-		chunk_free(ck);
-		close(avi_file->fd);
-		g_free(avi_file->wfx);
-		g_free(avi_file);
+	if (!chunk_in (avi_file->fio,ck))
+	  {
+		chunk_free (ck);
+		fileio_close (avi_file->fio);
+		g_free (avi_file->wfx);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 	/* data󥯤õ */
-	while (chunk_id(avi_file->fd)!=ckidWAVEDATA)
-		if (!chunk_next(avi_file->fd,ck)) {
-			chunk_free(ck);
-			close(avi_file->fd);
-			g_free(avi_file->wfx);
-			g_free(avi_file);
+	while (chunk_id (avi_file->fio) != CK_ID_WAVEDATA)
+		if (!chunk_next(avi_file->fio,ck))
+		  {
+			chunk_free (ck);
+			fileio_close (avi_file->fio);
+			g_free (avi_file->wfx);
+			g_free (avi_file);
 			return NULL;
-		}
+		  }
 	/* data󥯤Υ */
 	/* data󥯤(RIFF'AVI ' -> data) */
-	if ((size=chunk_size(avi_file->fd))==-1 || !chunk_in(avi_file->fd,ck)) {
-		chunk_free(ck);
-		close(avi_file->fd);
-		g_free(avi_file->wfx);
-		g_free(avi_file);
+	if ((size = chunk_size (avi_file->fio)) == -1
+											|| !chunk_in (avi_file->fio, ck))
+	  {
+		chunk_free (ck);
+		fileio_close (avi_file->fio);
+		g_free (avi_file->wfx);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 	/* եΥեåȤ */
-	if ((offset=lseek(avi_file->fd,0,SEEK_CUR))==-1) {
-		chunk_free(ck);
-		close(avi_file->fd);
-		g_free(avi_file->wfx);
-		g_free(avi_file);
+	if ((offset = fileio_seek (avi_file->fio, 0, FILEIO_SEEK_CUR)) == -1)
+	  {
+		chunk_free (ck);
+		fileio_close (avi_file->fio);
+		g_free (avi_file->wfx);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 	/* 󥯥ݥ󥿤 */
-	if (!chunk_free(ck)) {
-		close(avi_file->fd);
-		g_free(avi_file->wfx);
-		g_free(avi_file);
+	if (!chunk_free (ck))
+	  {
+		fileio_close (avi_file->fio);
+		g_free (avi_file->wfx);
+		g_free (avi_file);
 		return NULL;
-	}
+	  }
 	/* ե */
-	avi_file->length=size/wfx_get_block_align(avi_file->wfx);
-	avi_file->entries=1;				/* ǥåο */
+	avi_file->length = size / wfx_get_block_align (avi_file->wfx);
+	avi_file->entries = 1;				/* ǥåο */
 	/* ǥå */
-	avi_file->index=g_malloc(sizeof(AviIndex));
-	avi_file->index[0].offset=offset;
-	avi_file->index[0].size=size;
-	avi_file->index[0].flags=0;
+	avi_file->index = g_malloc (sizeof (AviIndex));
+	avi_file->index[0].offset = offset;
+	avi_file->index[0].size = size;
+	avi_file->index[0].flags = 0;
 	return avi_file;
 }
 
@@ -1017,7 +1016,7 @@ static AviFile *avi_open_wave(const gchar *file)
 /*	AVIAVIե빽¤Τ
 	    file,ե̾
 	   param,ȥ꡼ֹ
-	    type,streamtypeAUDIO/streamtypeVIDEO
+	    type,AVI_STREAM_AUDIO/AVI_STREAM_VIDEO
 	    rate,졼
 	   scale,
 	priority,ͥ
@@ -1043,7 +1042,7 @@ avi_open_file (const gchar *file, const gint param,
 			if (avi_file != NULL)
 			  {
 				if (type != NULL)
-					*type = streamtypeVIDEO;
+					*type = AVI_STREAM_VIDEO;
 				if (rate != NULL)
 					*rate = 15;
 				if (scale != NULL)
@@ -1061,7 +1060,7 @@ avi_open_file (const gchar *file, const gint param,
 			if (avi_file != NULL)
 			  {
 				if (type != NULL)
-					*type = streamtypeAUDIO;
+					*type = AVI_STREAM_AUDIO;
 				if (rate != NULL)
 					*rate = wfx_get_average_bytes_per_sec (avi_file->wfx);
 				if (scale != NULL)
@@ -1076,8 +1075,8 @@ avi_open_file (const gchar *file, const gint param,
 	  }
 	if (avi_file != NULL)
 	  {
-		avi_file->name = misc_get_full_path (file);	/* ե̾ */
-		avi_file->param = param;					/* ȥ꡼ֹ */
+		avi_file->name = fileio_get_full_path (file);	/* ե̾ */
+		avi_file->param = param;						/* ȥ꡼ֹ */
 	  }
 	return avi_file;
 }
@@ -1086,16 +1085,17 @@ avi_open_file (const gchar *file, const gint param,
 /*	AVIե빽¤Τ
 	avi_file,AVIե빽¤
 	     RET,TRUE:ｪλ,FALSE:顼										*/
-gboolean avi_release_file(AviFile *avi_file)
+gboolean
+avi_release_file (AviFile *avi_file)
 {
 	gboolean result;
 
-	result=avi_file->fd==-1 || close(avi_file->fd)==0;
-	g_free(avi_file->name);
-	g_free(avi_file->index);
-	g_free(avi_file->bmih);
-	g_free(avi_file->wfx);
-	g_free(avi_file);
+	result = avi_file->fio == NULL || fileio_close (avi_file->fio);
+	g_free (avi_file->name);
+	g_free (avi_file->index);
+	g_free (avi_file->bmih);
+	g_free (avi_file->wfx);
+	g_free (avi_file);
 	return result;
 }
 
@@ -1106,14 +1106,16 @@ gboolean avi_release_file(AviFile *avi_file)
 *                                                                             *
 ******************************************************************************/
 /*	AVI															*/
-gboolean avi_init(void)
+gboolean
+avi_init (void)
 {
-	return icm_init();
+	return icm_init ();
 }
 
 
 /*	AVIλ															*/
-gboolean avi_exit(void)
+gboolean
+avi_exit (void)
 {
-	return icm_exit();
+	return icm_exit ();
 }
