@@ -21,14 +21,6 @@
 
 
 #include "vmaid.h"
-#if defined USE_THREAD && ! defined USE_GTK2
-# ifdef HAVE_BITS_SIGSET_H
-#   include <bits/sigset.h>
-# endif /* HAVE_BITS_SIGSET_H */
-# ifdef HAVE_PTHREAD_H
-#   include <pthread.h>
-# endif /* HAVE_PTHREAD_H */
-#endif /* USE_THREAD and not USE_GTK2 */
 
 
 #define THREAD_MODE_EXIT 0
@@ -47,11 +39,7 @@ typedef struct ThreadList_Tag {
 	gint mode;			/* 0:λ,1:,2:¸,3:ե졼,4:ȿž */
 	gint percent;		/* ʹԾ(0...100) */
 #ifdef USE_THREAD
-# ifdef USE_GTK2
 	GThread *id;
-# else /* not USE_GTK2 */
-	pthread_t id;
-# endif /* not USE_GTK2 */
 #else /* not USE_THREAD */
 	gint id;
 #endif /* not USE_THREAD */
@@ -69,13 +57,8 @@ typedef struct ThreadList_Tag {
 	file,ե̾
 	 RET,TRUE:ｪλ,FALSE:顼											*/
 #ifdef USE_THREAD
-# ifdef USE_GTK2
 gboolean
 thread_insert (GThread *id, const gint mode, const gchar *file);
-# else /* not USE_GTK2 */
-gboolean
-thread_insert (pthread_t id, const gint mode, const gchar *file);
-# endif /* not USE_GTK2 */
 #else /* not USE_THREAD */
 gboolean
 thread_insert (gint id, const gint mode, const gchar *file);
@@ -86,13 +69,8 @@ thread_insert (gint id, const gint mode, const gchar *file);
 	 id,åID
 	RET,TRUE:ｪλ,FALSE:顼											*/
 #ifdef USE_THREAD
-# ifdef USE_GTK2
 gboolean
 thread_delete (GThread *id);
-# else /* not USE_GTK2 */
-gboolean
-thread_delete (pthread_t id);
-# endif /* not USE_GTK2 */
 #else /* not USE_THREAD */
 gboolean
 thread_delete(gint id);
@@ -104,13 +82,8 @@ thread_delete(gint id);
 	percent,ʹԾ
 	    RET,TRUE:³,FALSE:											*/
 #ifdef USE_THREAD
-# ifdef USE_GTK2
 gboolean
 thread_idling (GThread *id, const gint percent);
-# else /* not USE_GTK2 */
-gboolean
-thread_idling (pthread_t id, const gint percent);
-# endif /* not USE_GTK2 */
 #else /* not USE_THREAD */
 gboolean
 thread_idling (gint id, const gint percent);
