@@ -26,7 +26,7 @@
 typedef struct ToolBar_Tag {
 	gchar *name;
 	gchar **xpm;
-	GtkSignalFunc callback;
+	GtkItemFactoryCallback callback;
 	gpointer user_data;
 	GtkWidget *item;
 } ToolBar;
