@@ -66,9 +66,6 @@ typedef struct VmaidWindow_Tag {
 enum {
     TARGET_VMAID
 };
-enum {
-    TARGET_STRING
-};
 
 
 extern gboolean caret;                  /* キャレットの形 */
@@ -80,17 +77,13 @@ extern gchar *history_files[10];        /* ファイルの履歴 */
 extern gchar *open_path;                /* 開くのパス */
 extern gchar *save_path;                /* 名前を付けて保存のパス */
 extern gchar *clipboard_scenario;       /* クリップボードのテキスト */
-extern gchar *arg_text;                 /* プロセス間通信用変数 */
 extern gint def_width,def_height;       /* デフォルトのウインドウのサイズ */
 extern gint history;                    /* ファイルの履歴 */
-extern gint instance;                   /* プロセス間通信用変数 */
 extern gint default_view;               /* ウインドウが作成時の初期値 */
 extern guint default_rate;              /* ウインドウが作成時の初期値 */
 extern guint timer_id;                  /* タイマID */
 extern GdkAtom atom_targets;            /* ターゲット */
 extern GdkAtom atom_scenario;           /* シナリオオブジェクト */
-extern GdkAtom atom_videomaid0;         /* プロセス間通信用アトム */
-extern GdkAtom atom_videomaid1;         /* プロセス間通信用アトム */
 extern GdkBitmap *bitmap0;              /* 波背景 */
 extern GdkBitmap *bitmap1;              /* 網背景 */
 extern GtkWidget *window;               /* ウインドウ */
